@@ -74,13 +74,15 @@ class BaseAppConfigModel(configuration.ConfigModel):
 
 class RecurringTask(object):
 
-    def __init__(self, p_name, p_handler_method, p_interval=DEFAULT_TASK_INTERVAL, p_fixed_schedule=False):
+    def __init__(self, p_name, p_handler_method, p_interval=DEFAULT_TASK_INTERVAL, p_fixed_schedule=False,
+                 p_ignore_exceptions=False):
 
         self.name = p_name
         self.handler_method = p_handler_method
         self.interval = p_interval
         self.next_execution = None
         self.fixed_schedule = p_fixed_schedule
+        self.ignore_exceptions = p_ignore_exceptions
 
     def __lt__(self, p_other):
         return self.next_execution < p_other
@@ -147,6 +149,11 @@ class BaseApp(daemon.Daemon):
         self._latest_request = None
         self._partial_basic_init_executed = False
         self._full_basic_init_executed = False
+        self._active_signals = [signal.SIGTERM, signal.SIGINT]
+        self._done = False
+
+        if not tools.is_windows():
+            self._active_signals.append(signal.SIGHUP)
 
         if self._languages is None:
             self._languages = DEFAULT_LANGUAGES
@@ -280,20 +287,22 @@ class BaseApp(daemon.Daemon):
     def reevaluate_configuration(self):
         pass
 
-    def handle_sighup(self, p_signum, p_stackframe):
+    def handle_signal(self, p_signum, p_stackframe):
 
         fmt = "Received signal %d" % p_signum
         _ = p_stackframe
         self._logger.info(fmt)
+        self._done = True
 
         raise exceptions.SignalHangUp()
 
     def install_handlers(self):
 
-        signal.signal(signal.SIGTERM, self.handle_sighup)
-        signal.signal(signal.SIGHUP, self.handle_sighup)
-        signal.signal(signal.SIGINT, self.handle_sighup)  # CTRL-C
-        signal.pthread_sigmask(signal.SIG_UNBLOCK, [signal.SIGTERM, signal.SIGHUP, signal.SIGINT])
+        for signal_id in self._active_signals:
+            signal.signal(signal_id, self.handle_signal)
+
+        if not tools.is_windows():
+            signal.pthread_sigmask(signal.SIG_UNBLOCK, self._active_signals)
 
     def prepare_services(self, p_full_startup=True):
 
@@ -321,6 +330,7 @@ class BaseApp(daemon.Daemon):
     def event_queue(self):
 
         self._done = False
+        self._logger.info("Entering event queue...")
 
         while not self._done:
             try:
@@ -339,7 +349,9 @@ class BaseApp(daemon.Daemon):
                         fmt = "Sleeping for {seconds} seconds (or until next signal)"
                         self._logger.debug(fmt.format(seconds=wait_in_seconds))
 
-                        signal.pthread_sigmask(signal.SIG_UNBLOCK, [signal.SIGTERM, signal.SIGHUP])
+                        if not tools.is_windows():
+                            signal.pthread_sigmask(signal.SIG_UNBLOCK, self._active_signals)
+
                         time.sleep(wait_in_seconds)
 
                     except exceptions.SignalHangUp as e:
@@ -368,7 +380,7 @@ class BaseApp(daemon.Daemon):
                     task_executed = True
 
                     while task_executed:
-                        task = self._recurring_tasks[0]
+                        task : RecurringTask = self._recurring_tasks[0]
                         now = datetime.datetime.utcnow()
 
                         if now > task:
@@ -379,7 +391,16 @@ class BaseApp(daemon.Daemon):
 
                             fmt = "Executing task {task} {secs:.3f} [s] behind schedule... *** START ***"
                             self._logger.debug(fmt.format(task=task.name, secs=delay))
-                            task.handler_method()
+
+                            try:
+                                task.handler_method()
+
+                            except Exception as e:
+                                self._logger.error(f"Exception {str(e)}  while executing task {task.name}")
+
+                                if not task.ignore_exceptions:
+                                    raise e
+
                             fmt = "Executing task {task} {secs:.3f} [s] behind schedule... *** END ***"
                             self._logger.debug(fmt.format(task=task.name, secs=delay))
 
@@ -412,6 +433,8 @@ class BaseApp(daemon.Daemon):
             if self._arguments.single_run:
                 self._done = True
 
+        self._logger.info("Leaving event queue...")
+
     def track_downtime(self, p_downtime):
 
         fmt = "Detected delay of {seconds} seconds -> adding to downtime timer"
