@@ -25,11 +25,10 @@ from python_base_app import log_handling
 from python_base_app.test import base_test
 from python_base_app.test import test_audio_handler
 from python_base_app.test import test_audio_player
-from python_base_app.test import test_configuration
-from python_base_app.test import test_pytest
 from python_base_app.test import test_base_ci_toolbox
 from python_base_app.test import test_base_web_server
-from python_base_app.test import test_ldap_user_handler
+from python_base_app.test import test_configuration
+from python_base_app.test import test_pytest
 from python_base_app.test import test_unix_user_handler
 
 
@@ -58,10 +57,6 @@ def add_test_cases(p_test_suite, p_config_filename=None):
         p_test_suite=p_test_suite,
         p_test_unit_class=test_base_web_server.TestBaseWebServer, p_config_filename=p_config_filename)
 
-    base_test.add_tests_in_test_unit(
-        p_test_suite=p_test_suite,
-        p_test_unit_class=test_ldap_user_handler.TestLdapUserHandler, p_config_filename=p_config_filename)
-
     base_test.add_tests_in_test_unit(
         p_test_suite=p_test_suite,
         p_test_unit_class=test_unix_user_handler.TestUnixUserHandler, p_config_filename=p_config_filename)
